@@ -375,7 +375,7 @@ def fix_db(filename):
                                 params['database_uri'])
         content = content.replace('auth.define_tables()',\
             auth_user+'auth.define_tables(migrate = settings.migrate)')
-    content+ = """
+    content += """
 mail.settings.server = settings.email_server
 mail.settings.sender = settings.email_sender
 mail.settings.login = settings.email_login
@@ -575,7 +575,7 @@ def create(options):
     model = os.path.join(request.folder,'..',app,
                          'models','db_wizard_populate.py')
     if os.path.exists(model): os.unlink(model)
-    if options.populate_database:
+    if options.populate_database and session.app['tables']:
         file = open(model,'wb')
         try:
             file.write(populate(session.app['tables']))
