@@ -17,6 +17,7 @@ import fnmatch
 import os
 import copy
 import random
+import __builtin__
 from storage import Storage, List
 from template import parse_template
 from restricted import restricted, compile2
@@ -111,6 +112,7 @@ class LoadFactory(object):
             if not isinstance(args,(list,tuple)):
                 args = [args]
             c = c or request.controller
+
             other_request = globals.Request()
             other_request.application = request.application
             other_request.controller = c
@@ -119,37 +121,38 @@ class LoadFactory(object):
             other_request.args = List(args)
             other_request.folder = request.folder
             other_request.env = request.env
-            other_request.vars = request.vars
-            other_request.get_vars = request.get_vars
-            other_request.post_vars = request.post_vars
+            other_request.vars = vars
+            other_request.get_vars = vars
+            other_request.post_vars = Storage()
             other_response = globals.Response()
             other_request.env.http_web2py_component_location = \
                 request.env.path_info
-            other_request.env.http_web2py_component_element = target
+            other_request.env.http_web2py_component_element = other_request.cid = target
             other_response.view = '%s/%s.%s' % (c,f, other_request.extension)
 
             other_environment = copy.copy(self.environment)
             other_response._view_environment = other_environment
             other_environment['request'] = other_request
             other_environment['response'] = other_response
-            page = run_controller_in(c, f, other_environment)
 
+            ## some magic here because current are thread-locals
+
+            original_request, current.request = current.request, other_request
+            original_response, current.response = current.response, other_response
+            page = run_controller_in(c, f, other_environment)
             if isinstance(page, dict):
                 other_response._vars = page
                 for key in page:
                     other_response._view_environment[key] = page[key]
                 run_view_in(other_response._view_environment)
                 page = other_response.body.getvalue()
+            current.request, current.response = original_request, original_response
             js = None
             if ajax_trap:
                 link = html.URL(request.application, c, f, r=request,
                                 args=args, vars=vars, extension=extension,
                                 user_signature=user_signature)
                 js = "web2py_trap_form('%s','%s');" % (link, target)
-            # not sure about this
-            # for (name,value) in other_response.headers:
-            #     if name == 'web2py-component-command':
-            #         js += value
             script = js and html.SCRIPT(js,_type="text/javascript") or ''
             return html.TAG[''](html.DIV(html.XML(page),**attr),script)
 
@@ -229,6 +232,8 @@ def build_environment(request, response, session):
     current.T = environment['T'] = translator(request)
     current.cache = environment['cache'] = Cache(request)
 
+    __builtins__['__import__'] = __builtin__.__import__
+    environment['__builtins__'] = __builtins__
     environment['HTTP'] = HTTP
     environment['redirect'] = redirect
     environment['request'] = request
@@ -342,7 +347,7 @@ def run_models_in(environment):
         compiled=False
     paths = (path, os.path.join(path,c), os.path.join(path,c,f))
     for model in models:
-        if not os.path.split(model)[0] in paths:
+        if not os.path.split(model)[0] in paths and c!='appadmin':
             continue
         elif compiled:
             code = read_pyc(model)
@@ -437,9 +442,8 @@ def run_view_in(environment):
     badv = 'invalid view (%s)' % response.view
     patterns = response.generic_patterns or []
     regex = re.compile('|'.join(fnmatch.translate(r) for r in patterns))
-    allow_generic = regex.search('%s/%s.%s' % (request.controller,
-                                               request.function,
-                                               request.extension))
+    short_action =  '%(controller)s/%(function)s.%(extension)s' % request
+    allow_generic = patterns and regex.search(short_action)
     if not isinstance(response.view, str):
         ccode = parse_template(response.view, os.path.join(folder, 'views'),
                                context=environment)
