@@ -33,12 +33,15 @@ import hashlib
 
 regex_crlf = re.compile('\r|\n')
 
+join = ''.join
+
 __all__ = [
     'A',
     'B',
     'BEAUTIFY',
     'BODY',
     'BR',
+    'BUTTON',
     'CENTER',
     'CODE',
     'DIV',
@@ -277,7 +280,7 @@ def URL(
     if extension:
         function += '.' + extension
 
-    if regex_crlf.search(''.join([application, controller, function, other])):
+    if regex_crlf.search(join([application, controller, function, other])):
         raise SyntaxError, 'CRLF Injection Detected'
     url = rewrite.url_out(r, env, application, controller, function,
                           args, other, scheme, host, port)
@@ -776,7 +779,7 @@ class DIV(XmlComponent):
             fa += ' %s="%s"' % (name, xmlescape(value, True))
 
         # get the xml for the inner components
-        co = ''.join([xmlescape(component) for component in
+        co = join([xmlescape(component) for component in
                      self.components])
 
         return (fa, co)
@@ -1270,6 +1273,11 @@ class A(DIV):
         return DIV.xml(self)
 
 
+class BUTTON(DIV):
+    
+    tag = 'button'
+
+
 class EM(DIV):
 
     tag = 'em'
@@ -1331,7 +1339,7 @@ class CODE(DIV):
         highlight_line = self.attributes.get('highlight_line', None)
         styles = self['styles'] or {}
         return highlight(
-            ''.join(self.components),
+            join(self.components),
             language=language,
             link=link,
             counter=counter,
@@ -1419,6 +1427,16 @@ class TFOOT(DIV):
         self._wrap_components(TR, TR)
 
 
+class COL(DIV):
+
+    tag = 'col'
+
+
+class COLGROUP(DIV):
+
+    tag = 'colgroup'
+
+
 class TABLE(DIV):
     """
     TABLE Component.
@@ -1432,7 +1450,7 @@ class TABLE(DIV):
     tag = 'table'
 
     def _fixup(self):
-        self._wrap_components((TR, TBODY, THEAD, TFOOT), TR)
+        self._wrap_components((TR, TBODY, THEAD, TFOOT, COL, COLGROUP), TR)
 
 class I(DIV):
 
