@@ -24,7 +24,7 @@ import threading
 import urllib
 from storage import Storage, List
 from http import HTTP
-from fileutils import abspath
+from fileutils import abspath, read_file
 from settings import global_settings
 
 logger = logging.getLogger('web2py.rewrite')
@@ -192,9 +192,7 @@ def load(routes='routes.py', app=None, data=None, rdict=None):
                 path = abspath('applications', app, routes)
             if not os.path.exists(path):
                 return
-            routesfp = open(path, 'r')
-            data = routesfp.read().replace('\r\n','\n')
-            routesfp.close()
+            data = read_file(path).replace('\r\n','\n')
 
         symbols = {}
         try:
@@ -601,7 +599,7 @@ def regex_filter_out(url, e=None):
     return url
 
 
-def filter_url(url, method='get', remote='0.0.0.0', out=False, app=False, lang=None, 
+def filter_url(url, method='get', remote='0.0.0.0', out=False, app=False, lang=None,
         domain=(None,None), env=False, scheme=None, host=None, port=None):
     "doctest/unittest interface to regex_filter_in() and regex_filter_out()"
     regex_url = re.compile(r'^(?P<scheme>http|https|HTTP|HTTPS)\://(?P<host>[^/]*)(?P<uri>.*)')
@@ -1183,3 +1181,4 @@ def get_effective_router(appname):
     if not routers or appname not in routers:
         return None
     return Storage(routers[appname])  # return a copy
+
