@@ -16,9 +16,15 @@ Contributors:
 
 import os
 import re
+import cgi
 import cStringIO
-import restricted
-
+import logging
+try:
+    from restricted import RestrictedError
+except:
+    def RestrictedError(a,b,c):
+        logging.error(str(a)+':'+str(b)+':'+str(c))
+        return RuntimeError
 
 class Node(object):
     """
@@ -406,7 +412,7 @@ class TemplateParser(object):
         """
         Raise an error using itself as the filename and textual content.
         """
-        raise restricted.RestrictedError(self.name, text or self.text, message)
+        raise RestrictedError(self.name, text or self.text, message)
 
     def _get_file_text(self, filename):
         """
@@ -429,9 +435,7 @@ class TemplateParser(object):
         # try to read the text.
         try:
             fileobj = open(filepath, 'rb')
-
             text = fileobj.read()
-
             fileobj.close()
         except IOError:
             self._raise_error('Unable to open included view file: ' + filepath)
@@ -809,7 +813,7 @@ def parse_template(filename,
             text = fp.read()
             fp.close()
         except IOError:
-            raise restricted.RestrictedError(filename, '', 'Unable to find the file')
+            raise RestrictedError(filename, '', 'Unable to find the file')
     else:
         text = filename.read()
 
@@ -860,7 +864,35 @@ def render(content = "hello world",
     '012'
     """
     # Here to avoid circular Imports
-    import globals
+    try:
+        from globals import Response
+    except:
+        # Working standalone. Build a mock Response object.
+        class Response():
+            def __init__(self):
+                self.body = cStringIO.StringIO()
+            def write(self, data, escape=True):
+                if not escape:
+                    self.body.write(str(data))
+                elif hasattr(data,'xml') and callable(data.xml):
+                    self.body.write(data.xml())
+                else:
+                    # make it a string
+                    if not isinstance(data, (str, unicode)):
+                        data = str(data)
+                    elif isinstance(data, unicode):
+                        data = data.encode('utf8', 'xmlcharrefreplace')
+                    data = cgi.escape(data, True).replace("'","&#x27;")
+                    self.body.write(data)
+
+        # A little helper to avoid escaping.
+        class NOESCAPE():
+            def __init__(self, text):
+                self.text = text
+            def xml(self):
+                return self.text
+        # Add it to the context so we can use it.
+        context['NOESCAPE'] = NOESCAPE
 
     # If we don't have anything to render, why bother?
     if not content and not stream and not filename:
@@ -876,7 +908,7 @@ def render(content = "hello world",
             stream = cStringIO.StringIO(content)
 
     # Get a response class.
-    context['response'] = globals.Response()
+    context['response'] = Response()
 
     # Execute the template.
     code = str(TemplateParser(stream.read(), context=context, path=path, lexers=lexers, delimiters=delimiters))
@@ -896,3 +928,4 @@ def render(content = "hello world",
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
+
