@@ -6,10 +6,15 @@ import re
 
 filename = sys.argv[1]
 
-data = open(filename, 'r').read()
+datafile = open(filename, 'r')
+try:
+    data = datafile.read()
+finally:
+    datafile.close()
 data = re.compile('\s*{\s*').sub(' { ', data)
 data = re.compile('\s*;\s*').sub('; ', data)
 data = re.compile('\s*}\s*').sub(' }\n', data)
 data = re.compile('[ ]+').sub(' ', data)
 
 print data
+
